/*******************************************************************************
* File Name: irt_timer1.c  
* Version 1.50
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <irt_timer1.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START irt_timer1_intc` */

/* `#END` */


/*******************************************************************************
* Function Name: irt_timer1_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void irt_timer1_Start(void)
{
    /* For all we know the interrupt is active. */
    irt_timer1_Disable();

    /* Set the ISR to point to the irt_timer1 Interrupt. */
    irt_timer1_SetVector(irt_timer1_Interrupt);

    /* Set the priority. */
    irt_timer1_SetPriority(irt_timer1_INTC_PRIOR_NUMBER);

    /* Enable it. */
    irt_timer1_Enable();
}

/*******************************************************************************
* Function Name: irt_timer1_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void irt_timer1_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    irt_timer1_Disable();

    /* Set the ISR to point to the irt_timer1 Interrupt. */
    irt_timer1_SetVector(address);

    /* Set the priority. */
    irt_timer1_SetPriority(irt_timer1_INTC_PRIOR_NUMBER);

    /* Enable it. */
    irt_timer1_Enable();
}

/*******************************************************************************
* Function Name: irt_timer1_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void irt_timer1_Stop(void) 
{
    /* Disable this interrupt. */
    irt_timer1_Disable();
}

/*******************************************************************************
* Function Name: irt_timer1_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for irt_timer1.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(irt_timer1_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START irt_timer1_Interrupt` */
	my_isr_timer1();
    /* `#END` */

    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (irt_timer1__ES2_PATCH ))      
            irt_timer1_ISR_PATCH();
        #endif
    #endif
}

/*******************************************************************************
* Function Name: irt_timer1_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling irt_timer1_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use irt_timer1_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void irt_timer1_SetVector(cyisraddress address) 
{
    CY_SET_REG16(irt_timer1_INTC_VECTOR, (uint16) address);
}

/*******************************************************************************
* Function Name: irt_timer1_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress irt_timer1_GetVector(void) 
{
    return (cyisraddress) CY_GET_REG16(irt_timer1_INTC_VECTOR);
}

/*******************************************************************************
* Function Name: irt_timer1_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling irt_timer1_Start
*   or irt_timer1_StartEx will override any effect this method would have had. 
*	This method should only be called after irt_timer1_Start or 
*	irt_timer1_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void irt_timer1_SetPriority(uint8 priority) 
{
    *irt_timer1_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: irt_timer1_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 irt_timer1_GetPriority(void) 
{
    uint8 priority;


    priority = *irt_timer1_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: irt_timer1_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void irt_timer1_Enable(void) 
{
    /* Enable the general interrupt. */
    *irt_timer1_INTC_SET_EN = irt_timer1__INTC_MASK;
}

/*******************************************************************************
* Function Name: irt_timer1_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 irt_timer1_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*irt_timer1_INTC_SET_EN & irt_timer1__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: irt_timer1_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void irt_timer1_Disable(void) 
{
    /* Disable the general interrupt. */
    *irt_timer1_INTC_CLR_EN = irt_timer1__INTC_MASK;
}

/*******************************************************************************
* Function Name: irt_timer1_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void irt_timer1_SetPending(void) 
{
    *irt_timer1_INTC_SET_PD = irt_timer1__INTC_MASK;
}

/*******************************************************************************
* Function Name: irt_timer1_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void irt_timer1_ClearPending(void) 
{
    *irt_timer1_INTC_CLR_PD = irt_timer1__INTC_MASK;
}
